import * as solid_js from 'solid-js';
import { Component, JSX } from 'solid-js';
import * as atomic_router from 'atomic-router';
import { RouteInstance, RouteParams, RouteQuery, createHistoryRouter } from 'atomic-router';
import * as history from 'history';
import * as effector from 'effector';

declare const createRouteView: <Props>(route: RouteInstance<any> | RouteInstance<any>[], View: Component<Props>) => (props: Props) => solid_js.JSX.Element;

declare const createRoutesView: (config: {
    routes: {
        route: RouteInstance<any> | RouteInstance<any>[];
        view: Component<any>;
    }[];
    notFound?: Component<any>;
}) => () => solid_js.JSX.Element;

declare type Props<Params extends RouteParams> = {
    to: RouteInstance<Params> | string;
    params?: Params;
    query?: RouteQuery;
    activeClass?: string;
    inactiveClass?: string;
} & Exclude<JSX.AnchorHTMLAttributes<HTMLAnchorElement>, 'href'>;
declare function Link<Params extends RouteParams>(props: Props<Params>): JSX.Element;

declare type RouteProps<Params extends RouteParams> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: Component;
};
declare function Route<Params>(props: RouteProps<Params>): solid_js.JSX.Element;

declare type Router = ReturnType<typeof createHistoryRouter>;
declare const RouterContext: solid_js.Context<{
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<any>;
    setHistory: effector.Event<any>;
    push: effector.Effect<Pick<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "path" | "params" | "query" | "method">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    routeNotFound: effector.Event<void>;
} | null>;
declare function RouterProvider(props: {
    router: Router;
    children: JSX.Element;
}): JSX.Element;
declare function useRouter(): {
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<any>;
    setHistory: effector.Event<any>;
    push: effector.Effect<Pick<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "path" | "params" | "query" | "method">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    routeNotFound: effector.Event<void>;
};

export { Link, Route, RouterContext, RouterProvider, createRouteView, createRoutesView, useRouter };
